@@ -15,7 +15,7 @@ from typing import *
 from typing import BinaryIO
 from urllib.request import urlopen
 
-from PIL.Image import Image, open as img_open
+from PIL.Image import open as img_open
 from PIL.ImageTk import PhotoImage
 
 from ..Enumerations import *
@@ -24,15 +24,14 @@ from ...Files import FilePath
 from ...Images import *
 from ...Json import Size
 from ...Models import URL
+from ...Names import nameof
 from ...debug import pp
-from ...nameof import nameof
 
 
 
 
 __all__ = [
     'BaseTkinterWidget', 'BaseTextTkinterWidget',
-    'Image', 'ImageTk',
     'CommandMixin', 'ImageMixin',
     'CurrentValue', 'CallWrapper',
     'tk', 'ttk', 'tkEvent', 'URL',
@@ -170,7 +169,7 @@ class BaseTkinterWidget(tk.Widget, ABC):
 
         if parent: parent.focus_set()
 
-        self.OnDisppearing()
+        self.OnDisappearing()
         if self._manager_ == Layout.pack:
             self.pack_forget()
             return self._hide()
@@ -215,7 +214,7 @@ class BaseTkinterWidget(tk.Widget, ABC):
         if color: self.configure(disabledforeground=color)
         return self
 
-    def UndindIDs(self, ids: Iterable[str] = None):
+    def UnbindIDs(self, ids: Iterable[str] = None):
         for item in ids: self.unbind(item or self.__bindings__)
 
     def Bind(self, sequence: Bindings = None, func: callable = None, add: bool = None) -> str:
@@ -393,7 +392,7 @@ class BaseTkinterWidget(tk.Widget, ABC):
     def OnAppearing(self):
         """ this is called just after widget appears. override to implement desired effects """
         pass
-    def OnDisppearing(self):
+    def OnDisappearing(self):
         """ this is called just before widget disappears. override to implement desired effects """
         pass
 
